function bode_supercap

%Calculates the input impedance of a supercapacitor.
%The model must have an input current source and voltage measurement.

model = 'Supercap_2600F_bode';

%Starting point for the trim function
u0 = 0;
y0 = 2.5

[X,U,Y,DX]=trim(model,[],u0,y0,[],[],1) %find the steady-state for an output of y0
sys=linmod(model, X, U) %get the state space matrices


%Calculate the frequency 
num_points = 33;
out = plbode(sys, [1 1], [1e-3 1e3], num_points);

f = out.F;
Z = out.G;  
R = real(Z);
X = imag(Z);

%Plot resistance and capacitance vs frequency
figure(2)
subplot(2,1,1)
semilogx(f, R, 'm');
ylabel('Resistance (\Omega)');
grid on;
hold on;
C = -1./(2*pi.*f.*X);
subplot(2,1,2)
semilogx(f, C); %ang_t);
ylabel('Capacitance (F)');
xlabel('Frequency (Hz)');
grid on;
xlim('manual')